'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var fs = require('fs');
var pathUtil = require('path');
function transformName(name) {
    if (!name) return '';
    return name.replace(/[A-Z]/g, function (ch, index) {
        if (index === 0) return ch.toLowerCase();
        return '-' + ch.toLowerCase();
    });
}

exports.default = function (babel) {
    var t = babel.types;


    return {
        visitor: {
            ImportDeclaration: function ImportDeclaration(path, _ref) {
                var opts = _ref.opts;
                var node = path.node;
                var cssName = opts.cssName,
                    jsName = opts.jsName,
                    dir = opts.dir,
                    noStyle = opts.noStyle;

                cssName = cssName || '@alife/next';
                jsName = jsName || '@alife/next';
                dir = dir || 'lib';
                if (!node) return;
                if (node.source.value === jsName) {
                    var jsBase = jsName + '/' + dir + '/',
                        cssBase = cssName + '/' + dir + '/';
                    node.specifiers.forEach(function (specifier) {
                        if (t.isImportSpecifier(specifier)) {
                            var comName = specifier.imported.name,
                                lcomName = transformName(comName),
                                libName = jsBase + lcomName,
                                libCssName = cssBase + lcomName + '/index.scss';
                            path.insertAfter(t.importDeclaration([t.ImportDefaultSpecifier(t.identifier(comName))], t.stringLiteral(libName)));
                            if (!noStyle) {
                                if (fs.existsSync(pathUtil.join('node_modules', t.stringLiteral(libCssName).value))) {
                                    path.insertAfter(t.importDeclaration([], t.stringLiteral(libCssName)));
                                }
                            }
                        }
                    });
                    path.remove();
                }
            }
        }
    };
};